require 'json'
require 'uri'
require 'net/http'
# see the URL below for information on how to write OpenStudio measures
# http://nrel.github.io/OpenStudio-user-documentation/measures/measure_writing_guide/

class IntroducirObjetosAdicionalesNecesariosParaLaSimulacion < OpenStudio::Ruleset::WorkspaceUserScript

  # human readable name
  def name
    return "Water Heater - Autosize"
  end

  # human readable description
  def description
    return "Water Heater - Autosize"
  end

  # human readable description of modeling approach
  def modeler_description
    return "WaterHeater:Sizing"
  end

  # define the arguments that the user will input
  def arguments(workspace)
    args = OpenStudio::Ruleset::OSArgumentVector.new

    # the name of the zone to add to the model
    # zone_name = OpenStudio::Ruleset::OSArgument.makeStringArgument("zone_name", true)
    # zone_name.setDisplayName("New zone name")
    # zone_name.setDescription("This name will be used as the name of the new zone.")
    # args << zone_name

    return args
  end 

  # define what happens when the measure is run
  def run(workspace, runner, user_arguments)
    super(workspace, runner, user_arguments)

    # use the built-in error checking 
    if !runner.validateUserArguments(arguments(workspace), user_arguments)
      return false
    end

    # reporting initial condition of model
    runner.registerInitialCondition("Comenzamos...")
    
    model = runner.lastOpenStudioModel
    if model.empty?
      runner.registerError("Cannot find last model.")
      return false
    end
    model = model.get



    #Lo introducimos si no es el edificio HE1
#    puts "edificio he1",JSON.parse(model.building.get.comment[2..-1])["edificioHE1"]
    
    # En las versiones anteriores a las 2.6 se llamaba Water Heater
    # Lo mantenemos por compatibilidad
    comprobamosSiEstaElTanque = workspace.getObjectsByTypeAndName("WaterHeater_Mixed".to_IddObjectType,"Water Heater")
    if not JSON.parse(model.building.get.comment[2..-1])["edificioHE1"] and not comprobamosSiEstaElTanque.empty?
      
      
        formatoTabla_string = "    
      WaterHeater:Sizing,
        Water Heater,   !- WaterHeater Name
        PeakDraw,                !- Design Mode
        0.50,                !- Time Storage Can Meet Peak Draw {hr}
        0.50,                     !- Time for Tank Recovery {hr}
        1.0;                     !- Nominal Tank Volume for Autosizing Plant Connections {m3}"      
        idfObject = OpenStudio::IdfObject::load(formatoTabla_string)
        object = idfObject.get
    	wsObject = workspace.addObject(object)
    
    end 
    
  comprobamosSiEstaElTanque = workspace.getObjectsByTypeAndName("WaterHeater_Mixed".to_IddObjectType,"Equipo Generacion ACS")
  if not JSON.parse(model.building.get.comment[2..-1])["edificioHE1"] and not comprobamosSiEstaElTanque.empty?
    
    
      formatoTabla_string = "    
    WaterHeater:Sizing,
    Equipo Generacion ACS,   !- WaterHeater Name
      PeakDraw,                !- Design Mode
      0.50,                !- Time Storage Can Meet Peak Draw {hr}
      0.50,                     !- Time for Tank Recovery {hr}
      1.0;                     !- Nominal Tank Volume for Autosizing Plant Connections {m3}"      
      idfObject = OpenStudio::IdfObject::load(formatoTabla_string)
      object = idfObject.get
    wsObject = workspace.addObject(object)
  
  end     
    
    






    # report final condition of model
    runner.registerFinalCondition("Fin")
    
    return true
 
  end
  


end 

# register the measure to be used by the application
IntroducirObjetosAdicionalesNecesariosParaLaSimulacion.new.registerWithApplication
